/*------------------------------------------------------------------------------
 * MyComponent - Component ::MDK Example:MyComponent
 * Copyright (c) 2016 ARM Germany GmbH. All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    EvrMyComponent.h
 * Purpose: Definition of debug events for MyComponent example
 * Rev.:    V1.0.0
 *----------------------------------------------------------------------------*/
  

#include "EventRecorder.h"              // Keil::Compiler:Event Recorder


#ifndef __STATIC_INLINE
  #define __STATIC_INLINE           static __inline
#endif
  

// Notation used in the MyComponent example:
//   "MyComponent Example" is the long component name
//   "MyCo" is the short component name
//
// The following prefix is used for identifiers:
//   Evt      local defines in this header file
//   EvtMyCo  event id values, whereby "MyCo" is the short name of "MyComponent"
//   EvrMyCo  event record functions, whereby "MyCo" is the short name of "MyComponent"

  
#define EvtMyCo_No 0x0A    /// < Number of the component with short name 'Comp'

#ifdef MyComp_DEBUG        // Define debug events
  
// Event id list for "MyComponent"
#define EvtMyCo_InitEntry         EventID (EventLevelAPI,   EvtMyCo_No, 0x00)
#define EvtMyCo_InitStatus        EventID (EventLevelAPI,   EvtMyCo_No, 0x01)
#define EvtMyCo_SendNoData        EventID (EventLevelError, EvtMyCo_No, 0x0A)
#define EvtMyCo_SendComplete      EventID (EventLevelOp,    EvtMyCo_No, 0x0B)
#define EvtMyCo_SendFailed        EventID (EventLevelError, EvtMyCo_No, 0x0C)
#define EvtMyCo_ReceiveNoData     EventID (EventLevelError, EvtMyCo_No, 0x15)
#define EvtMyCo_ReceiveComplete   EventID (EventLevelAPI,   EvtMyCo_No, 0x16)
#define EvtMyCo_ReceiveFailed     EventID (EventLevelError, EvtMyCo_No, 0x17)

#endif // MyComp_DEBUG


/**
  \brief  Event on \ref MyComp_initialize start (API)
 */
#ifdef EvtMyCo_InitEntry
  __STATIC_INLINE void EvrMyCo_InitEntry(void) {
    EventRecord2(EvtMyCo_InitEntry, 0, 0);
  }
#else
  #define EvrMyCo_InitEntry()
#endif


/**
  \brief  Event on \ref MyComp_initialize return (API)
  \param  status execution status value  
 */
#ifdef EvtMyCo_InitStatus
  __STATIC_INLINE void EvrMyCo_InitStatus(uint32_t status) {
    EventRecord2(EvtMyCo_InitStatus, status, 0);
  }
#else
  #define EvrMyCo_InitStatus(status)
#endif

/**
  \brief  Event on \ref MyComp_send no data passed (Error)
 */
#ifdef EvtMyCo_SendNoData
  __STATIC_INLINE void EvrMyCo_SendNoData(void) {
    EventRecord2(EvtMyCo_SendNoData, 0, 0);
  }
#else
  #define EvrMyCo_SendNoData()
#endif


/**
  \brief  Event on \ref MyComp_send - completed (Op)
  \param  size  number of bytes transferred
 */
#ifdef EvtMyCo_SendComplete
  __STATIC_INLINE void EvrMyCo_SendComplete(uint32_t size) {
    EventRecord2(EvtMyCo_SendComplete, size, 0);
  }
#else
  #define EvrMyCo_SendComplete(size)
#endif


/**
  \brief  Event on \ref MyComp_send - send failed (Error)
 */
#ifdef EvtMyCo_SendFailed
  __STATIC_INLINE void EvrMyCo_SendFailed(void) {
    EventRecord2(EvtMyCo_SendFailed, 0, 0);
  }
#else
  #define EvrMyCo_SendFailed()
#endif

/**
  \brief  Event on \ref MyComp_receive - no data received (Error)
 */
#ifdef  EvtMyCo_ReceiveNoData
  __STATIC_INLINE void EvrMyCo_ReceiveNoData(void) {
    EventRecord2(EvtMyCo_ReceiveNoData, 0, 0);
  }
#else
  #define EvrMyCo_ReceiveNoData()
#endif

/**
  \brief  Event on \ref MyComp_receive - completed (API)
  \param  size  number of bytes transferred
 */
#ifdef  EvtMyCo_ReceiveComplete
  __STATIC_INLINE void EvrMyCo_ReceiveComplete(uint32_t size) {
    EventRecord2(EvtMyCo_ReceiveComplete, size, 0);
  }
#else
  #define EvrMyCo_ReceiveComplete(size)
#endif

/**
  \brief  Event on \ref MyComp_receive - receive failed (Error)
 */
#ifdef  EvtMyCo_ReceiveFailed
  __STATIC_INLINE void EvrMyCo_ReceiveFailed(void) {
    EventRecord2(EvtMyCo_ReceiveFailed, 0, 0);
  }
#else
  #define EvrMyCo_ReceiveFailed()
#endif

