/*------------------------------------------------------------------------------
 * MyComponent - Component ::MDK Example:MyComponent
 * Copyright (c) 2016 ARM Germany GmbH. All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    MyComponent.c
 * Purpose: Example showing the usage of Software Component Views in MDK
 * Rev.:    V1.0.0
 *----------------------------------------------------------------------------*/
 
 
#include <stdint.h>
#include <stdio.h>
#include <string.h>

#define MyComp_DEBUG                               // enable debug events

#include "MyComponent.h"

struct MyComp_info_t MyComp_info;
struct MyComp_data_t MyComp_data;

// Initialize 
void MyComp_initialize (void) {
  EvrMyCo_InitEntry();                             // Record Event
  MyComp_info.version = 3;                         // Set information
  MyComp_info.channels = 1;
  MyComp_info.buffersize = sizeof(MyComp_data.buf);
  memset (&MyComp_data, sizeof(MyComp_data), 0);   // Zero initialize  
  MyComp_data.is_free = 1;
  EvrMyCo_InitStatus(1);                           // Record Event
}

// Send message to buffer
void MyComp_send (char* str) {
  if (str == NULL) {
    EvrMyCo_SendNoData ();                         // Record Event
    return;
  }
  if (MyComp_data.is_free == 1) {
    uint32_t str_size;
    str_size=strlen(str);
    strncpy(MyComp_data.buf, str, sizeof(MyComp_data.buf));
    MyComp_data.is_free = 0;
    EvrMyCo_SendComplete(str_size);                // Record Event
  } else {
    EvrMyCo_SendFailed();                          // Record Event             
  }
}

// Receive message from buffer
void MyComp_receive (char* str) {
  if (str == NULL) {
    EvrMyCo_ReceiveNoData ();                      // Record Event
    return;
  }
  if (MyComp_data.is_free == 0) {
    uint32_t str_size;
    strncpy(str, MyComp_data.buf, sizeof(MyComp_data.buf));
    str_size=strlen(str);
    MyComp_data.is_free = 1;
    EvrMyCo_ReceiveComplete(str_size);             // Record Event                 
  } else {
    EvrMyCo_ReceiveFailed();                       // Record Event                         
  }
}

